.. currentmodule:: flox

API Reference
-------------

Functions
~~~~~~~~~

.. autosummary::
    :toctree: generated/

    groupby_reduce
    xarray.xarray_reduce

Rechunking
~~~~~~~~~~

.. autosummary::
    :toctree: generated/

    rechunk_for_blockwise
    rechunk_for_cohorts
    xarray.rechunk_for_blockwise
    xarray.rechunk_for_cohorts

Visualization
~~~~~~~~~~~~~

.. autosummary::
    :toctree: generated/

    visualize.draw_mesh
    visualize.visualize_groups_1d
    visualize.visualize_cohorts_2d

Aggregation Objects
~~~~~~~~~~~~~~~~~~~

.. autosummary::
    :toctree: generated/

    Aggregation
    aggregations.sum_
    aggregations.nansum
